import type { ComputeConfig } from 'svelte-floating-ui';
import type { Action } from 'svelte/action';
import { type Writable } from 'svelte/store';
type OptionBase = {
    id: string;
    label: string;
    active: boolean;
    parent: OptionMenu | null;
    data?: Record<string, any>;
};
export type OptionSelect = OptionBase & {
    type: 'select';
    selected: boolean;
    isMulti: boolean;
};
export type InputOptionSelect = Partial<Omit<OptionSelect, 'label'>> & Pick<OptionSelect, 'label'>;
export type OptionMenu = OptionBase & {
    type: 'menu';
    hasSelected: boolean;
    subOptions: OptionItem[];
};
export type InputOptionMenu = Partial<Omit<OptionMenu, 'label' | 'subOptions'>> & Pick<OptionMenu, 'label'> & {
    subOptions: InputOptionItem[];
};
export type CloseOnSelect = 'never' | 'always' | 'not_multi';
export type Addition = {
    id: string;
    label: string;
};
export type SelectConfig = {
    closeOnSelect: CloseOnSelect;
    minSearchLength: number;
    triggerEvent?: 'contextmenu' | 'mouseup';
    activeOnOpen?: boolean;
    additions: Addition[];
    floatingUiOptions?: Partial<ComputeConfig>;
    useVirtualElement?: boolean;
};
export type AddOption = {
    id: string;
    searchText: string;
};
export type OptionItem = OptionSelect | OptionMenu;
export type InputOptionItem = InputOptionMenu | InputOptionSelect;
export type WritableElement = Writable<HTMLElement | null>;
export type WritableOptions = [Writable<HTMLElement[]>, string];
export declare const element: Action<HTMLElement, WritableElement | WritableOptions>;
export declare class Select {
    inputOptions: Writable<InputOptionItem[]>;
    config: SelectConfig;
    readonly elements: {
        search: Writable<HTMLInputElement | null>;
        options: Writable<HTMLElement[]>;
        trigger: Writable<HTMLElement | null>;
        content: Writable<HTMLElement | null>;
    };
    readonly events: {
        onSelect: Writable<OptionSelect>;
        onChange: Writable<OptionSelect>;
        onAdd: Writable<AddOption>;
    };
    readonly state: {
        isOpen: Writable<boolean>;
        selected: Writable<OptionSelect[]>;
        search: Writable<string>;
        options: Writable<OptionItem[]>;
        filteredOptions: Writable<OptionItem[]>;
        searchOptions: Writable<OptionSelect[]>;
        additionOptions: Writable<OptionSelect[]>;
    };
    constructor(inputOptions: InputOptionItem[], inputConfig?: Partial<SelectConfig>);
    private open;
    private close;
    selectOption(id: string): OptionSelect | null;
    addOption(id: string): null | undefined;
    getMenuOptions(): OptionMenu[];
    getOption(id: string): OptionItem | null;
    getSelectOption(id: string): OptionSelect | null;
    getActiveLeaf(): OptionItem | null;
    getActiveList(): OptionItem[];
    setActiveId(id: string | null): void;
    setActive(setOption: OptionItem | null): void;
    setPrevActive(): void;
    setNextActive(): void;
    setParentActive(): void;
    setChildActive(): void;
    resetSearch(): void;
    private onSearchChange;
    private isSearchOptionId;
    private isAddOptionId;
    private updateFilteredOptions;
    private updateSearchOptions;
    static toFlat(options: OptionItem[]): OptionItem[];
    static getParentLabels(option: OptionItem): string[];
    static toFlatSelect(options: OptionItem[]): OptionSelect[];
    private getSiblings;
    private setFirstActive;
    private getAllOptions;
    private getShowingSearchOptions;
    private static toSearchOption;
    private shouldClose;
    static inputToOptionItem(input: InputOptionItem, parent?: OptionItem): OptionItem;
    private updateAddableOption;
    onTriggerMouseUp(event: MouseEvent, isOpen: Writable<boolean>): void;
    onKeyDown(event: KeyboardEvent): void;
    onKeyUp(event: KeyboardEvent): void;
    private setUpFloatingUi;
}
export declare function filterText(option: OptionItem, input?: string): boolean;
export {};
